# antsibull\-fileutils Release Notes

**Topics**

- <a href="#v1-0-1">v1\.0\.1</a>
    - <a href="#release-summary">Release Summary</a>
    - <a href="#bugfixes">Bugfixes</a>
- <a href="#v1-0-0">v1\.0\.0</a>
    - <a href="#release-summary-1">Release Summary</a>

<a id="v1-0-1"></a>
## v1\.0\.1

<a id="release-summary"></a>
### Release Summary

Bugfix release\.

<a id="bugfixes"></a>
### Bugfixes

* Remove accidentally left\-in <code>print\(\)</code> statement in <code>antsibull\_fileutils\.io\.write\_file\(\)</code> \([https\://github\.com/ansible\-community/antsibull\-fileutils/pull/5](https\://github\.com/ansible\-community/antsibull\-fileutils/pull/5)\)\.

<a id="v1-0-0"></a>
## v1\.0\.0

<a id="release-summary-1"></a>
### Release Summary

Initial release\.
